# coding: utf-8
"""
レンダリング画像にガンマ補正をかけます
"""

__author__ = "CASPAR003 <caspar003@caspar003.info>"
__date__ = "2014-07-19/2014-07-19"
__version__ = "1.0"

def ca3_pe_gammacorrection(img, gamma):
    """
    画像にガンマ補正をかけます
    @param img   フィルタをかけたい画像（Shade imageオブジェクト）
    @param gamma モニタガンマ
    モニタガンマが2.2の場合，ガンマ補正をかけるときはgamma=2.2，リニアに戻すときはgamma=1.0/2.2を渡します．
    """
    import numpy as np
    
    # 作業用配列の確保
    matr = np.zeros(img.size)
    matg = np.zeros(img.size)
    matb = np.zeros(img.size)
    
    # Shade imageをnumpy arrayに代入
    for ix in range(img.size[0]):
        for iy in range(img.size[1]):
            matr[ix, iy], matg[ix, iy], matb[ix, iy] = img.get_pixel(ix, iy)
    
    # ガンマ補正
    matr = np.power(matr, 1.0/gamma)
    matg = np.power(matg, 1.0/gamma)
    matb = np.power(matb, 1.0/gamma)
    
    # numpy arrayをShade imageに戻す
    for ix in range(img.size[0]):
        for iy in range(img.size[1]):
            img.set_pixel(ix, iy, (matr[ix, iy], matg[ix, iy], matb[ix, iy]))
    return



if (__name__ == "__main__"):
    img = xshade.scene().rendering.image
    if (img is not None):
        ca3_pe_gammacorrection(img, 2.2)
        xshade.scene().rendering.update_image()
