# coding:utf-8
"""
レンダリングウィンドウにある画像にフィルタをかけてサムネイルとして保存します．
widgetから呼び出す用のスクリプトで読み込み時に[[FOOBAR]]を適当な文字列に置換して実行します．
"""

__author__ = "CASPAR003 <caspar003@caspar003.info>"
__date__ = "2014-07-26/2014-07-28"
__version__ = "1.0"

def createAfterImg(applyRenderingImage):
    """
    レンダリングウィンドウの内容をサムネイルとして保存します．
    @return "{0:d}.format(int)" レンダリング画像のハッシュ値．画像が存在しなかったときは"0"を返します．
    """
    
    import urllib
    import os
    import sys
    
    CurrentDir = "[[CURRENT_DIR]]"
    OutFileName = "ri_after.png"
    TmbFileName = "ri_thumb_after.png"
    ThumbneilSize = 280
    
    # パスを追加してフィルタモジュールをインポート
    sys.path.append(urllib.unquote(CurrentDir))
    import ca3_pe_aperturediffraction
    import ca3_pe_falloff
    import ca3_pe_gammacorrection
    import ca3_pe_reinhard
    import ca3_pe_whitebalance
    
    # レンダリング画像を取得
    try:
        img = xshade.scene().rendering.image
    except:
        img = None
    
    if (img is None):
        # 画像が存在しなければ作る
        img = xshade.create_image((ThumbneilSize, ThumbneilSize), 128)
        result = "{0:d}".format(0)
    else:
        # 画像が存在すればコピーを取る（本適用の時はコピー不要）
        if (not applyRenderingImage): img = img.duplicate()
        result = "{0:d}".format(img.__hash__())
        
        # フィルタを適用
        if ([[WHITEBALANCE.IS_ACTIVE]]):
            ca3_pe_whitebalance.ca3_pe_whitebalance(img, 6500, [[WHITEBALANCE.T]])
        if ([[FALLOFF.IS_ACTIVE]]):
            f = xshade.scene().camera.zoom
            ca3_pe_falloff.ca3_pe_falloff(img, f)
        if ([[APDIFFRAC.IS_ACTIVE]]):
            ca3_pe_aperturediffraction.ca3_pe_aperturediffraction(img, [[APDIFFRAC.F]])
        if ([[REINHARD.IS_ACTIVE]]):
            ca3_pe_reinhard.ca3_pe_reinhard(img, [[REINHARD.A]], [[REINHARD.LW]])
        if ([[GAMMA.IS_ACTIVE]]):
            ca3_pe_gammacorrection.ca3_pe_gammacorrection(img, [[GAMMA.GAMMA]])
    
    # 既にファイルが存在しているときは削除する
    outFilePath = urllib.unquote(CurrentDir) + "images/" + OutFileName
    if os.path.exists(outFilePath): os.remove(outFilePath)
    tmbFilePath = urllib.unquote(CurrentDir) + "images/" + TmbFileName
    if os.path.exists(tmbFilePath): os.remove(tmbFilePath)
    
    # 実寸の画像を保存
    img.save(outFilePath)
    
    # サムネイルサイズに縮小
    if (max(img.size) > ThumbneilSize):
        scale = float(ThumbneilSize) / float(max(img.size))
        img = img.duplicate((int(scale * img.size[0]), int(scale * img.size[1])), True, img.pixel_depth)
    
    img.save(tmbFilePath)
    
    # レンダリング画像を更新
    if (xshade.scene().rendering.image is not None): xshade.scene().rendering.update_image()
    
    return result

if (__name__ == "__main__"): result = createAfterImg([[APPLY_RENDERING_IMAGE]])
